@@ -777,6 +777,12 @@ sub exec_command {
 		}
 	}
 
+	# $PATH is removed by the environment filter by default
+	# adding back a default so called commands find their executables.
+	if (!exists $ENV{"PATH"}) {
+		$ENV{PATH} = $self->get_conf('PATH');
+	}
+
 	my $chrootenv = $self->get('Defaults')->{'ENV'};
 	foreach (keys %$chrootenv) {
 		$ENV{$_} = $chrootenv->{$_};
