@@ -415,6 +415,16 @@ sub begin_session {
 		return 0;
 	}
 
+	{
+		my (undef, undef, undef, $gid, undef) = getpwuid($UID);
+		my $egid = POSIX::getegid();
+		if ($gid != $egid) {
+			print STDERR ("W: Your primary effective group id does not match "
+				  . "the group id of your user account. As a result, unshare "
+				  . "mode cannot be used. Did you use newgrp?");
+		}
+	}
+
 	@cmd = (
 		'unshare',
 		# comment to guide perltidy line wrapping
@@ -434,6 +444,28 @@ sub begin_session {
 		return 0;
 	}
 
+	if (
+		0 != system "/usr/libexec/sbuild-usernsexec",
+		(map { join ":", @{$_} } @idmap),
+		'--', 'touch', $rootdir
+	) {
+		print STDERR "E: unable to access $rootdir\n";
+		my $acc;
+		for my $comp (split '/', $rootdir) {
+			$acc .= "$comp/";
+			if (
+				0 != system "/usr/libexec/sbuild-usernsexec",
+				(map { join ":", @{$_} } @idmap),
+				'--', 'test', '-x', $acc
+			) {
+				print STDERR
+				  "W: first inaccessible directory along path: $acc\n";
+				last;
+			}
+		}
+		return 0;
+	}
+
 	if ($self->get_conf('UNSHARE_MMDEBSTRAP_AUTO_CREATE')) {
 		my $found = 0;
 		if ($self->get_conf('MMDEBSTRAP') =~ /\//
