@@ -430,15 +430,9 @@ sub setup {
 	# builds can (optionally) trust an external key for the duration of the
 	# build.
 	#
-	# Keys have to be in a format that apt expects to land in
-	# /etc/apt/trusted.gpg.d as they are just copied to there. We could also
-	# support more formats by first importing them using gpg and then
-	# exporting them but that would require gpg to be installed inside the
-	# chroot.
+	# Keys have to be in a format that apt supports in /etc/apt/trusted.gpg.d,
+	# as they are just copied to there.
 	if (@{ $self->get_conf('EXTRA_REPOSITORY_KEYS') }) {
-		my $host = $self->get('Host');
-		# remember whether running gpg worked or not
-		my $has_gpg = 1;
 		for my $repokey (@{ $self->get_conf('EXTRA_REPOSITORY_KEYS') }) {
 			debug("Adding archive key: $repokey\n");
 			if (!-f $repokey) {
@@ -447,70 +441,57 @@ sub setup {
 				);
 				return 0;
 			}
-			# key might be armored but apt requires keys in binary format
-			# We first try to run gpg from the host to convert the key into
-			# binary format (this works even when the key already is in binary
-			# format).
 			my $tmpfilename = mktemp("/tmp/tmp.XXXXXXXXXX");
-			if ($has_gpg == 1) {
-				$host->run_command({
-						COMMAND => [
-							'gpg',        '--yes',
-							'--batch',    '--output',
-							$tmpfilename, '--dearmor',
-							$repokey
-						],
-						USER => $self->get_conf('BUILD_USER'),
-					});
-				if ($?) {
-					# don't try to use gpg again in later loop iterations
-					$has_gpg = 0;
-				}
-			}
-# If that doesn't work, then we manually convert the key
-# as it is just base64 encoded data with a header and footer.
-#
-# The decoding of armored gpg keys can even be done from a shell
-# script by using:
-#
-#    awk '/^$/{ x = 1; } /^[^=-]/{ if (x) { print $0; } ; }' | base64 -d
-#
-# As explained by dkg here: https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=831409#67
-			if ($has_gpg == 0) {
-				# Test if we actually have an armored key. Otherwise, no
-				# conversion is needed.
-				open my $fh, '<', $repokey;
-				read $fh, my $first_line, 36;
-				if ($first_line eq "-----BEGIN PGP PUBLIC KEY BLOCK-----") {
-					# Read the remaining part of the line until the newline.
-					# We do it like this because the line might contain
-					# additional whitespace characters or \r\n newlines.
-					<$fh>;
-					open my $out, '>', $tmpfilename;
-					# the file is an armored gpg key, so we convert it to the
-					# binary format
-					my $header = 1;
-					while (my $line = <$fh>) {
-						chomp $line;
-						# an empty line marks the end of the header
-						if ($line eq "") {
-							$header = 0;
-							next;
-						}
-						if ($header == 1) {
-							next;
-						}
-						# the footer might contain lines starting with an
-						# equal sign or minuses
-						if ($line =~ /^[=-]/) {
-							last;
-						}
-						print $out (decode_base64($line));
+			# Key might be armored but apt requires keys in binary format.
+			# We manually convert the key as it is just base64 encoded data
+			# with a header and footer, and then we do not need to invoke gpg.
+			#
+			# The decoding of armored gpg keys can even be done from a shell
+			# script by using:
+			#
+			# awk '/^$/{ x = 1; } /^[^=-]/{ if (x) { print $0; } ; }' \
+			#   | base64 -d
+			#
+			# As explained by dkg here:
+			# https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=831409#67
+			open my $fh,  '<', $repokey;
+			open my $out, '>', $tmpfilename;
+			read $fh, my $first_line, 36;
+			# Test if we actually have an armored key. Otherwise, no
+			# conversion is needed.
+			if ($first_line eq "-----BEGIN PGP PUBLIC KEY BLOCK-----") {
+				# Read the remaining part of the line until the newline.
+				# We do it like this because the line might contain
+				# additional whitespace characters or \r\n newlines.
+				<$fh>;
+				# the file is an armored gpg key, so we convert it to the
+				# binary format
+				my $header = 1;
+				while (my $line = <$fh>) {
+					chomp $line;
+					# an empty line marks the end of the header
+					if ($line eq "") {
+						$header = 0;
+						next;
 					}
-					close $out;
+					if ($header == 1) {
+						next;
+					}
+					# the footer might contain lines starting with an
+					# equal sign or minuses
+					if ($line =~ /^[=-]/) {
+						last;
+					}
+					print $out (decode_base64($line));
+				}
+			} else {
+				print $out $first_line;    # initially read bytes
+				while (my $line = <$fh>) {
+					print $out $line;
 				}
-				close $fh;
 			}
+			close $out;
+			close $fh;
 			# we could use incrementing integers to number the extra
 			# repository keys but mktemp will also make sure that the new name
 			# doesn't exist yet and avoids the complexity of an additional
